==> audacity-src-1.3.0b.tar.gz: audacity-src-1.3.0b-beta/images/EditButtons.h <==
#ifdef USE_AQUA_THEME
#include "Aqua/Up.xpm"
#include "Aqua/Down.xpm"    
#include "Aqua/Hilite.xpm"
#else
#include "EditButtons/Up.xpm"
#include "EditButtons/Down.xpm"      
#include "EditButtons/Hilite.xpm"       
#endif

#include "EditButtons/CopyAlpha.xpm"
#include "EditButtons/CutAlpha.xpm"
#include "EditButtons/Paste.xpm"       
#include "EditButtons/Redo.xpm"           
#include "EditButtons/Silence.xpm"     
#include "EditButtons/Trim.xpm"        
#include "EditButtons/Undo.xpm"
#include "EditButtons/Copy.xpm"        
#include "EditButtons/Cut.xpm"        
#include "EditButtons/PasteAlpha.xpm"  
#include "EditButtons/RedoAlpha.xpm"  
#include "EditButtons/SilenceAlpha.xpm"  
#include "EditButtons/TrimAlpha.xpm"  
#include "EditButtons/UndoAlpha.xpm" 
#include "EditButtons/ZoomIn.xpm"
#include "EditButtons/ZoomInAlpha.xpm"
#include "EditButtons/ZoomOut.xpm"
#include "EditButtons/ZoomOutAlpha.xpm"
#include "EditButtons/ZoomSel.xpm"
#include "EditButtons/ZoomSelAlpha.xpm"
#include "EditButtons/ZoomFit.xpm"
#include "EditButtons/ZoomFitAlpha.xpm"
//#include "EditButtons/ZoomToggle.xpm"
//#include "EditButtons/ZoomToggleAlpha.xpm"
#include "EditButtons/PasteDisabled.xpm"       
#include "EditButtons/RedoDisabled.xpm"           
#include "EditButtons/SilenceDisabled.xpm"     
#include "EditButtons/TrimDisabled.xpm"        
#include "EditButtons/UndoDisabled.xpm"
#include "EditButtons/CopyDisabled.xpm"        
#include "EditButtons/CutDisabled.xpm"      
#include "EditButtons/ZoomInDisabled.xpm"
#include "EditButtons/ZoomOutDisabled.xpm"
#include "EditButtons/ZoomSelDisabled.xpm"
#include "EditButtons/ZoomFitDisabled.xpm"
//#include "EditButtons/ZoomToggleDisabled.xpm"

==> audacity-src-1.3.2.tar.gz: audacity-src-1.3.2-beta/images/EditButtons.h <==
#ifdef USE_AQUA_THEME
#include "Aqua/Up.xpm"
#include "Aqua/Down.xpm"    
#include "Aqua/Hilite.xpm"
#else
#include "EditButtons/Up.xpm"
#include "EditButtons/Down.xpm"      
#include "EditButtons/Hilite.xpm"       
#endif

#include "EditButtons/CopyAlpha.xpm"
#include "EditButtons/CutAlpha.xpm"
#include "EditButtons/Paste.xpm"       
#include "EditButtons/Redo.xpm"           
#include "EditButtons/Silence.xpm"     
#include "EditButtons/Trim.xpm"        
#include "EditButtons/Undo.xpm"
#include "EditButtons/Copy.xpm"        
#include "EditButtons/Cut.xpm"        
#include "EditButtons/PasteAlpha.xpm"  
#include "EditButtons/RedoAlpha.xpm"  
#include "EditButtons/SilenceAlpha.xpm"  
#include "EditButtons/TrimAlpha.xpm"  
#include "EditButtons/UndoAlpha.xpm" 
#include "EditButtons/ZoomIn.xpm"
#include "EditButtons/ZoomInAlpha.xpm"
#include "EditButtons/ZoomOut.xpm"
#include "EditButtons/ZoomOutAlpha.xpm"
#include "EditButtons/ZoomSel.xpm"
#include "EditButtons/ZoomSelAlpha.xpm"
#include "EditButtons/ZoomFit.xpm"
#include "EditButtons/ZoomFitAlpha.xpm"
#include "EditButtons/ZoomToggle.xpm"
#include "EditButtons/ZoomToggleAlpha.xpm"
#include "EditButtons/PasteDisabled.xpm"       
#include "EditButtons/RedoDisabled.xpm"           
#include "EditButtons/SilenceDisabled.xpm"     
#include "EditButtons/TrimDisabled.xpm"        
#include "EditButtons/UndoDisabled.xpm"
#include "EditButtons/CopyDisabled.xpm"        
#include "EditButtons/CutDisabled.xpm"      
#include "EditButtons/ZoomInDisabled.xpm"
#include "EditButtons/ZoomOutDisabled.xpm"
#include "EditButtons/ZoomSelDisabled.xpm"
#include "EditButtons/ZoomFitDisabled.xpm"
#include "EditButtons/ZoomToggleDisabled.xpm"
